_BUILDTIME_GURUMDDS_HOME="/usr/share/gurumdds/cmake/../../.."

# Give priority to the GurumDDS installation found when the workspace was built, if it's valid.
# If it's not valid, the current value of the GURUMDDS_HOME environment variable will be used.
# The one detected at buildtime may refer to an invalid path for users using "fat archive" binaries, for example.
if [ -d "$_BUILDTIME_GURUMDDS_HOME" ]; then
  if [ ! -z "$GURUMDDS_HOME" -a "$GURUMDDS_HOME" != "$_BUILDTIME_GURUMDDS_HOME" ]; then
    echo "[gurumdds_cmake_module] Warning: GURUMDDS_HOME environment variable is set to [[$GURUMDDS_HOME]]." \
      "When the workspace was built, GurumDDS was found at [[$_BUILDTIME_GURUMDDS_HOME]]," \
      "which is what will actually be used." \
      "Manually modify the environment now if this is not the configuration you want." 1>&2
  fi
  _GURUMDDS_HOME_TO_USE=$_BUILDTIME_GURUMDDS_HOME
else
  if [ -z "$GURUMDDS_HOME" ]; then
    echo "[gurumdds_cmake_module] Warning:" \
      "The location at which GurumDDS was found when the workspace was built [[$_BUILDTIME_GURUMDDS_HOME]]" \
      "does not point to a valid directory, and the GURUMDDS_HOME environment variable has not been set." \
      "Support for GurumDDS will not be available." 1>&2
    unset _BUILDTIME_GURUMDDS_HOME
    return
  fi

  if [ ! -d "$GURUMDDS_HOME" ]; then
    echo "[gurumdds_cmake_module] Warning:" \
      "Neither the location at which GurumDDS was found when the workspace was built [[$_BUILDTIME_GURUMDDS_HOME]]" \
      "nor the GurumDDS_HOME environment variable [[$GURUMDDS_HOME]] point to a valid directory". \
      "Support for GurumDDS will not be available." 1>&2
    unset _BUILDTIME_GURUMDDS_HOME
    return
  fi
  _GURUMDDS_HOME_TO_USE=$GURUMDDS_HOME
fi

export GURUMDDS_HOME="$_GURUMDDS_HOME_TO_USE"

# detect if running on Darwin platform
_UNAME=`uname -s`
_IS_DARWIN=0
if [ "$_UNAME" = "Darwin" ]; then
  _IS_DARWIN=1
fi
unset _UNAME

if [ $_IS_DARWIN -eq 0 ]; then
  _LIB_PATH=LD_LIBRARY_PATH
else
  _LIB_PATH=DYLD_LIBRARY_PATH
fi

eval _PATHS=\"\$$_LIB_PATH\"
if [ -z "$_PATHS" ]; then
  eval export $_LIB_PATH=\"$GURUMDDS_HOME/lib\"
else
  _IFS_SAVE=$IFS
  IFS=':'
  if [ "$AMENT_SHELL" = "zsh" ]; then
    ament_zsh_to_array _PATHS
  fi
  for _PATH in $_PATHS; do
    if [ -n "$_PATH" -a "$_PATH" = "$GURUMDDS_HOME/lib" ]; then
      _FLAG=1
    fi
  done
  if [ -z "$_FLAG" ]; then
    eval export $_LIB_PATH=\"$GURUMDDS_HOME/lib:\$$_LIB_PATH\"
  fi
  IFS=$_IFS_SAVE
  unset _IFS_SAVE
  unset _FLAG
fi
unset _PATHS

unset _LIB_PATH
unset _IS_DARWIN

unset _GURUMDDS_HOME_TO_USE
unset _BUILDTIME_GURUMDDS_HOME
